@@ -1,6 +1,16 @@
 from parser_libraries import functions as f
 from bs4 import BeautifulSoup
 import os
+import logging
+import logging.handlers
+
+
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
+handler = logging.handlers.SysLogHandler(address='/dev/log')
+formatter = logging.Formatter(f'%(module)s.{__name__}: %(message)s')
+handler.setFormatter(formatter)
+log.addHandler(handler)
 
 URL = 'https://sledcom.ru/sk_russia/leaders'
 HOST = 'https://sledcom.ru'
@@ -26,6 +36,7 @@ def get_person(html):
 
 
 def parser():
+    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
     html = f.get_html(URL)
     person = []
     if html.status_code == 200:
@@ -33,6 +44,7 @@ def parser():
         if box == 1:
             return [{'code': 1, 'script': os.path.basename(__file__)}]
         person.append(box)
+        log.debug("The script stops working")
         return person
     else:
         return [{'code': 2, 'script': os.path.basename(__file__)}]
