@@ -1,12 +1,23 @@
 from parser_libraries import functions as f
 from parser_libraries import SQL as SQL
 from bs4 import BeautifulSoup
+import os
+import logging
+import logging.handlers
 
 
 COMPLEX_URL = 'https://ru.wikipedia.org/wiki/%D0%A1%D1%83%D0%B1%D1%8A%D0%B5%D0%BA%D1%82%D1%8B_%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D0%B9%D1%81%D0%BA%D0%BE%D0%B9_%D0%A4%D0%B5%D0%B4%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%B8'
 HOST = 'https://ru.wikipedia.org/'
 
 
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
+handler = logging.handlers.SysLogHandler(address='/dev/log')
+formatter = logging.Formatter(f'%(module)s.{__name__}: %(message)s')
+handler.setFormatter(formatter)
+log.addHandler(handler)
+
+
 def get_yandex_image(name):
     info = SQL.get_con_info()
     link = 'https://yandex.ru/images/search?text=' + name[0] + '%20' + name[1] + '%20' + name[2]
@@ -23,7 +34,6 @@ def get_wiki_person(link, work_id):
     if full_name.find('(') != -1:
         full_name = full_name[:full_name.find('(')]
     full_name = f.get_name(full_name)
-    print(full_name)
     soup = soup.find('table', class_='infobox')
     try:
         image_link = soup.find('td', class_='infobox-image').find('img').get('srcset')
@@ -71,7 +81,6 @@ def get_page(link):
                         if title.rfind(' ') == len(title) - 1:
                             title = title[:-1]
                         full_name = [title[:title.find(',')].lower(), title[title.find(',')+1:title.rfind(' ')].lower(), title[title.rfind(' ')+1:].lower()]
-                        print(full_name)
                         for part in full_name:
                             part = part.replace(' ', '')
                         image_link = 'https:' + get_yandex_image(full_name)
@@ -95,6 +104,7 @@ def get_page(link):
 
 
 def parser():
+    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
     html = f.get_html(COMPLEX_URL)
     soup = BeautifulSoup(html.text, 'html.parser')
     links = []
@@ -112,8 +122,9 @@ def parser():
             links.append(HOST + a.find('a').get('href'))
     i = 1
     for link in links:
-        print(f'{i}/{len(links)+1}')
+        log.debug(f'{i}/{len(links)+1}')
         i+=1
         a = get_page(link)
         people.extend(a)
-    return people
\ No newline at end of file
+    log.debug("The script stops working")
+    return people
